@@ -7,8 +7,6 @@ package Group::Git::Taggers::Perl;
 # $Revision$, $Source$, $Date$
 
 use Moo;
-use strict;
-use warnings;
 use namespace::autoclean;
 use version;
 use Carp;
@@ -16,7 +14,7 @@ use English qw/ -no_match_vars /;
 
 extends 'Group::Git::Taggers';
 
-our $VERSION = version->new('0.0.3');
+our $VERSION = version->new('0.0.4');
 
 sub match {
     my ($self, $project) = @_;
@@ -24,7 +22,6 @@ sub match {
     return -f 'Makefile.PL' || -f 'Build.PL' || -f 'dist.ini';
 }
 
-__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -36,7 +33,7 @@ Group::Git::Taggers::Perl - Tags repositories as containing Perl code for Group:
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Taggers::Perl version 0.0.3
+This documentation refers to Group::Git::Taggers::Perl version 0.0.4
 
 =head1 SYNOPSIS
 
@@ -49,7 +46,7 @@ This documentation refers to Group::Git::Taggers::Perl version 0.0.3
 
 =head1 DESCRIPTION
 
-Looks at a repository and determines if it is a Perl repository based weather
+Looks at a repository and determines if it is a Perl repository based whether
 it contains one of the following files:
 
 =over 4
